.. _om:

.. raw:: html

    <br>

.. title:: om


.. raw:: html

    <center>

om
==

.. raw:: html

    </center>
    <br>

| 1 Mon, 14 Jan 2013 11:48:20 +0000 "Keijzer, N.D. (OM Haarlem-Alkmaar)" <n.d.keijzer@om.nl> RE: verzoek aan de officier van justitie om tot strafrechtelijke vervolging over te gaan
|

| Geachte heer Thate,

| U geeft aan misstanden bij de GGZ en in de wetgeving te willen aankaarten. 
| Het Openbaar Ministerie komt echter pas in beeld als er echt aantoonbaar strafbare feiten (volgens het wetboek van strafrecht) zijn gepleegd. Hoewel het voor u vermoedelijk als onrechtvaardig voelt, valt dit zo op het eerste 
| gezicht buiten het bereik van het strafrecht. Wellicht kunt u melding doen bij de IGZ (Inspectie van de Gezondheidszorg) http://www.igz.nl/organisatie

| Ik hoop u hiermee van dienst te zijn geweest,

| Hoogachtend,

| N. Keijzer
| Openbaar Ministerie Noord-Holland
